@@ -1,7 +1,7 @@
 package Perinci::Examples::ArgsAs;
 
-our $DATE = '2020-04-29'; # DATE
-our $VERSION = '0.820'; # VERSION
+our $DATE = '2021-01-30'; # DATE
+our $VERSION = '0.821'; # VERSION
 
 use 5.010001;
 use strict;
@@ -100,7 +100,7 @@ Perinci::Examples::ArgsAs - Demonstrate various values of `args_as` function met
 
 =head1 VERSION
 
-This document describes version 0.820 of Perinci::Examples::ArgsAs (from Perl distribution Perinci-Examples), released on 2020-04-29.
+This document describes version 0.821 of Perinci::Examples::ArgsAs (from Perl distribution Perinci-Examples), released on 2021-01-30.
 
 =head1 DESCRIPTION
 
@@ -134,11 +134,11 @@ Examples:
 
 =item * Without the optional arg3:
 
- args_as_array("abc", 10); # -> ["abc", 10]
+ args_as_array("abc", 10); # -> [200, "OK", ["abc", 10], {}]
 
 =item * With the optional arg3:
 
- args_as_array("def", 20, 0.5); # -> ["def", 20, 0.5]
+ args_as_array("def", 20, 0.5); # -> [200, "OK", ["def", 20, 0.5], {}]
 
 =back
 
@@ -184,11 +184,11 @@ Examples:
 
 =item * Without the optional arg3:
 
- args_as_arrayref(["abc", 10]); # -> [["abc", 10]]
+ args_as_arrayref(["abc", 10]); # -> [200, "OK", [["abc", 10]], {}]
 
 =item * With the optional arg3:
 
- args_as_arrayref(["def", 20, 0.5]); # -> [["def", 20, 0.5]]
+ args_as_arrayref(["def", 20, 0.5]); # -> [200, "OK", [["def", 20, 0.5]], {}]
 
 =back
 
@@ -234,11 +234,15 @@ Examples:
 
 =item * Without the optional arg3:
 
- args_as_hash(arg1 => "abc", arg2 => 10); # -> ["arg2", 10, "arg1", "abc"]
+ args_as_hash(arg1 => "abc", arg2 => 10); # -> [200, "OK", ["arg2", 10, "arg1", "abc"], {}]
 
 =item * With the optional arg3:
 
- args_as_hash(arg1 => "def", arg2 => 20, arg3 => 0.5); # -> ["arg3", 0.5, "arg1", "def", "arg2", 20]
+ args_as_hash(arg1 => "def", arg2 => 20, arg3 => 0.5);
+
+Result:
+
+ [200, "OK", ["arg3", 0.5, "arg2", 20, "arg1", "def"], {}]
 
 =back
 
@@ -284,7 +288,7 @@ Examples:
 
 =item * Without the optional arg3:
 
- args_as_hashref({ arg1 => "abc", arg2 => 10 }); # -> [{ arg1 => "abc", arg2 => 10 }]
+ args_as_hashref({ arg1 => "abc", arg2 => 10 }); # -> [200, "OK", [{ arg1 => "abc", arg2 => 10 }], {}]
 
 =item * With the optional arg3:
 
@@ -292,7 +296,7 @@ Examples:
 
 Result:
 
- [{ arg1 => "def", arg2 => 20, arg3 => 0.5 }]
+ [200, "OK", [{ arg1 => "def", arg2 => 20, arg3 => 0.5 }], {}]
 
 =back
 
@@ -344,7 +348,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013, 2012, 2011 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
